{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "platanus_b",
                "assemble"
            ],
            "hints": [
                {
                    "dockerPull": "nigyta/platanus_b:1.1.0",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                "-f",
                "$(inputs.fastq1)",
                "$(inputs.fastq2)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "FASTQ File1 (forward)",
                    "doc": "FASTQ File2 (forward)",
                    "id": "#platanusB_assemble.cwl/fastq1"
                },
                {
                    "type": "File",
                    "label": "FASTQ File2 (reverse)",
                    "doc": "FASTQ File2 (reverse)",
                    "id": "#platanusB_assemble.cwl/fastq2"
                },
                {
                    "type": "string",
                    "label": "prefix of output files",
                    "doc": "Prefix of output files (default: out)",
                    "default": "out",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#platanusB_assemble.cwl/prefix"
                },
                {
                    "type": "int",
                    "label": "number of threads",
                    "doc": "Number of threads",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#platanusB_assemble.cwl/threads"
                }
            ],
            "id": "#platanusB_assemble.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix)_contig.fa"
                    },
                    "id": "#platanusB_assemble.cwl/contig"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix)_32merFrq.tsv"
                    },
                    "id": "#platanusB_assemble.cwl/kmerfreq"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "platanus_b",
                "iterate"
            ],
            "hints": [
                {
                    "dockerPull": "nigyta/platanus_b:1.1.0",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                "-c",
                "$(inputs.contig)",
                "-IP1",
                "$(inputs.fastq1)",
                "$(inputs.fastq2)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#platanusB_iterate.cwl/contig"
                },
                {
                    "type": "File",
                    "id": "#platanusB_iterate.cwl/fastq1"
                },
                {
                    "type": "File",
                    "id": "#platanusB_iterate.cwl/fastq2"
                },
                {
                    "type": "string",
                    "label": "prefix of output files",
                    "doc": "Prefix of output files (default: out)",
                    "default": "out",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#platanusB_iterate.cwl/prefix"
                },
                {
                    "type": "int",
                    "label": "number of threads",
                    "doc": "Number of threads",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#platanusB_iterate.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix)_iterativeAssembly.fa"
                    },
                    "id": "#platanusB_iterate.cwl/scaffold"
                }
            ],
            "id": "#platanusB_iterate.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "platanus_b",
                "assemble"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "nigyta/platanus_b:1.1.0",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                "-f",
                "$(inputs.fastq1)",
                "$(inputs.fastq2)",
                "-repeat"
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "FASTQ File1 (forward)",
                    "doc": "FASTQ File2 (forward)",
                    "id": "#platanusB_repeat.cwl/fastq1"
                },
                {
                    "type": "File",
                    "label": "FASTQ File2 (reverse)",
                    "doc": "FASTQ File2 (reverse)",
                    "id": "#platanusB_repeat.cwl/fastq2"
                },
                {
                    "type": "string",
                    "label": "prefix of output files",
                    "doc": "Prefix of output files (default: out)",
                    "default": "out",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#platanusB_repeat.cwl/prefix"
                },
                {
                    "type": "int",
                    "label": "number of threads",
                    "doc": "Number of threads",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#platanusB_repeat.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix)_contig.fa",
                        "outputEval": "${self[0].basename=inputs.prefix + '_repeat.fa'; return self;}"
                    },
                    "id": "#platanusB_repeat.cwl/repeat_contig"
                }
            ],
            "id": "#platanusB_repeat.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/fastq1"
                },
                {
                    "type": "File",
                    "id": "#main/fastq2"
                },
                {
                    "type": "string",
                    "default": "out",
                    "id": "#main/prefix"
                },
                {
                    "type": "int",
                    "default": 1,
                    "id": "#main/threads"
                }
            ],
            "steps": [
                {
                    "run": "#platanusB_assemble.cwl",
                    "in": [
                        {
                            "source": "#main/fastq1",
                            "id": "#main/assemble/fastq1"
                        },
                        {
                            "source": "#main/fastq2",
                            "id": "#main/assemble/fastq2"
                        },
                        {
                            "source": "#main/prefix",
                            "id": "#main/assemble/prefix"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/assemble/threads"
                        }
                    ],
                    "out": [
                        "#main/assemble/contig",
                        "#main/assemble/kmerfreq"
                    ],
                    "id": "#main/assemble"
                },
                {
                    "run": "#platanusB_iterate.cwl",
                    "in": [
                        {
                            "source": "#main/assemble/contig",
                            "id": "#main/iterate/contig"
                        },
                        {
                            "source": "#main/fastq1",
                            "id": "#main/iterate/fastq1"
                        },
                        {
                            "source": "#main/fastq2",
                            "id": "#main/iterate/fastq2"
                        },
                        {
                            "source": "#main/prefix",
                            "id": "#main/iterate/prefix"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/iterate/threads"
                        }
                    ],
                    "out": [
                        "#main/iterate/scaffold"
                    ],
                    "id": "#main/iterate"
                },
                {
                    "run": "#platanusB_repeat.cwl",
                    "in": [
                        {
                            "source": "#main/fastq1",
                            "id": "#main/repeat_assemble/fastq1"
                        },
                        {
                            "source": "#main/fastq2",
                            "id": "#main/repeat_assemble/fastq2"
                        },
                        {
                            "source": "#main/prefix",
                            "id": "#main/repeat_assemble/prefix"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/repeat_assemble/threads"
                        }
                    ],
                    "out": [
                        "#main/repeat_assemble/repeat_contig"
                    ],
                    "id": "#main/repeat_assemble"
                }
            ],
            "outputs": [
                {
                    "id": "#main/contig",
                    "type": "File",
                    "outputSource": "#main/assemble/contig"
                },
                {
                    "id": "#main/kmerfreq",
                    "type": "File",
                    "outputSource": "#main/assemble/kmerfreq"
                },
                {
                    "id": "#main/scaffold",
                    "type": "File",
                    "outputSource": "#main/iterate/scaffold"
                },
                {
                    "id": "#main/repeat",
                    "type": "File",
                    "outputSource": "#main/repeat_assemble/repeat_contig"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
